job "democratic-csi-controller" {
  datacenters = ["dc1"]

  group "iscsi" {
    count = 1

    task "iscsi-controller" {
      driver = "docker"

      config {
        image = "danielberteaud/democratic-csi:latest"

        args = [
          "--csi-version=1.5.0",
          "--csi-name=org.democratic-csi.iscsi",
          "--driver-config-file=${NOMAD_SECRETS_DIR}/config.yml",
          "--log-level=info",
          "--csi-mode=controller",
          "--server-socket=/csi/csi.sock",
        ]

        network_mode = "host"
        privileged   = true
        userns_mode  = "host"
      }

      vault {
        policies = ["democratic-csi"]
      }

      template {
        data = <<-EOF
driver: freenas-api-iscsi
instance_id:

httpConnection:
  protocol: http
  host: freenas
  port: 80
  apiKey: {{ with secret "kv/service/democratic-csi" }}{{ .Data.data.truenas_api_key }}{{ end }}
  allowInsecure: false
  apiVersion: 2

zfs:
  datasetParentName: zpool/csi/iscsi
  detachedSnapshotsDatasetParentName: zpool/csi/iscsisnap
  zvolEnableReservation: false
  zvolBlocksize: 16K

iscsi:
  targetPortals: 
    - 10.99.3.27:3260
  interface:

  namePrefix: ""
  nameSuffix: ""

  targetGroups:
    - targetGroupPortalGroup: 1
      targetGroupInitiatorGroup: 1
      targetGroupAuthType: None
      targetGroupAuthGroup: 1

  extentInsecureTpc: true
  extentXenCompat: false
  extentDisablePhysicalBlocksize: false
  extentBlocksize: 512
  extentRpm: "SSD"
  extentAvailThreshold: 0
driver: freenas-api-iscsi

instance_id:

httpConnection:
  protocol: [[ .common.namespace ]]
  host: {{ env "TRUENAS_API_HOST" }}
  port: {{ env "TRUENAS_API_PORT" }}
  apiKey: {{ with secret (printf "%skv/service/democratic-csi" (env "VAULT_PREFIX")) }}{{ .Data.data.truenas_api_key }}{{ end }}
  allowInsecure: {{ env "TRUENAS_API_INSECURE" }}
  apiVersion: 2

zfs:
  datasetParentName: {{ env "ZFS_PARENT" }}
  detachedSnapshotsDatasetParentName: {{ env "ZFS_SNAP_PARENT" }}
  zvolCompression:
  zvolDedup:
  zvolEnableReservation: {{ env "ZFS_RESERVATION" }}
  zvolBlocksize: {{ env "ZFS_BLOCKSIZE" }}

iscsi:
  targetPortals:
{{ range $idx, $portal := (env "ISCSI_PORTALS" | split ",") }}
    - {{ $portal }}{{ end }}
  interface:

  namePrefix: ""
  nameSuffix: ""

  targetGroups:
    - targetGroupPortalGroup: 1
      targetGroupInitiatorGroup: 1
      targetGroupAuthType: None
      targetGroupAuthGroup:

  extentInsecureTpc: true
  extentXenCompat: false
  extentDisablePhysicalBlocksize: false
  extentBlocksize: 512
  extentRpm: "SSD"
  extentAvailThreshold: 0

        EOF

        destination = "${NOMAD_SECRETS_DIR}/config.yml"
      }

      csi_plugin {
        # must match --csi-name arg
        id        = "org.democratic-csi.iscsi"
        type      = "controller"
        mount_dir = "/csi"
      }

      resources {
        cpu    = 100
        memory = 192
      }
    }
  }

  group "nfs" {
    count = 1

    task "nfs-controller" {
      driver = "docker"

      config {
        image = "danielberteaud/democratic-csi:latest"

        args = [
          "--csi-version=1.5.0",
          "--csi-name=org.democratic-csi.nfs",
          "--driver-config-file=${NOMAD_SECRETS_DIR}/config.yml",
          "--log-level=silly",
          "--csi-mode=controller",
          "--server-socket=/csi/csi.sock",
        ]

        network_mode = "host"
        privileged   = true
        userns_mode  = "host"
      }

      vault {
        policies = ["democratic-csi"]
      }

      template {
        data = <<-EOF
driver: freenas-api-nfs
instance_id:

httpConnection:
  protocol: http
  host: freenas
  port: 80
  apiKey: {{ with secret "kv/service/democratic-csi" }}{{ .Data.data.truenas_api_key }}{{ end }}
  allowInsecure: false
  apiVersion: 2

zfs:
  datasetParentName: zpool/csi/nfs
  detachedSnapshotsDatasetParentName: zpool/csi/nfssnap
  datasetEnableQuotas: false
  datasetEnableReservation: false
  datasetPermissionsMode: "0770"
  datasetPermissionsUser: 0
  datasetPermissionsGroup: 0

nfs:
  shareHost: 10.99.3.27
  shareAlldirs: false
  shareAllowedHosts: []
  shareAllowedNetworks:
    - 10.99.9.0/24
  shareMaprootUser: root
  shareMaprootGroup: root
  shareMapallUser: ""
  shareMapallGroup: ""
        EOF

        destination = "${NOMAD_SECRETS_DIR}/config.yml"
      }

      csi_plugin {
        # must match --csi-name arg
        id        = "org.democratic-csi.nfs"
        type      = "controller"
        mount_dir = "/csi"
      }

      resources {
        cpu    = 100
        memory = 192
      }
    }
  }
}
