job "democratic-csi-controller" {
  datacenters = ["dc1"]

[[ if eq .democratic_csi.enable_iscsi true ]]
  group "iscsi" {

    count = [[ .democratic_csi.ctl_count ]]
    
    task "iscsi-controller" {
      
      driver = "docker"

      config {
        image = "[[ .democratic_csi.image ]]"
        args = [
          "--csi-version=1.5.0",
          "--csi-name=org.democratic-csi.iscsi",
          "--driver-config-file=${NOMAD_SECRETS_DIR}/config.yml",
          "--log-level=info",
          "--csi-mode=controller",
          "--server-socket=/csi/csi.sock"
        ]

        network_mode = "host"
        privileged   = true
        userns_mode  = "host"
      }

      vault {
        policies = ["democratic-csi[[ .common.env_suffix ]]"]
      }

      template {
        data =<<-EOF
[[ template "iscsi_controller" . ]]
[[ fileContents "files/iscsi/controller.yml.tpl" ]]
        EOF
        destination = "${NOMAD_SECRETS_DIR}/config.yml"
      }

      csi_plugin {
        # must match --csi-name arg
        id        = "org.democratic-csi.iscsi"
        type      = "controller"
        mount_dir = "/csi"
      }

      resources {
        cpu    = [[ .democratic_csi.ctl_resources.cpu ]]
        memory = [[ .democratic_csi.ctl_resources.memory ]]
      }
    }
  }
[[ end ]]

[[ if eq .democratic_csi.enable_nfs true ]]
  group "nfs" {

    count = [[ .democratic_csi.ctl_count ]]

    task "nfs-controller" {

      driver = "docker"

      config {
        image = "[[ .democratic_csi.image ]]"

        args = [
          "--csi-version=1.5.0",
          "--csi-name=org.democratic-csi.nfs",
          "--driver-config-file=${NOMAD_SECRETS_DIR}/config.yml",
          "--log-level=silly",
          "--csi-mode=controller",
          "--server-socket=/csi/csi.sock"
        ]

        network_mode = "host"
        privileged   = true
        userns_mode  = "host"
      }

      vault {
        policies = ["democratic-csi[[ .common.env_suffix ]]"]
      }

      template {
        data        = <<-EOF
[[ template "nfs_controller" . ]]
        EOF
        destination = "${NOMAD_SECRETS_DIR}/config.yml"
      }

      csi_plugin {
        # must match --csi-name arg
        id        = "org.democratic-csi.nfs"
        type      = "controller"
        mount_dir = "/csi"
      }

      resources {
        cpu    = [[ .democratic_csi.node_resources.cpu ]]
        memory = [[ .democratic_csi.node_resources.memory ]]
      }
    }
  }
[[ end ]]
}
