variable "image" {
  description = "Docker image to use"
  type        = string
  default     = "danielberteaud/democratic-csi:latest"
}

variable "enable_iscsi" {
  description = "Enable iSCSI driver"
  type        = bool
  default     = true
}

variable "enable_nfs" {
  description = "Enable NFS driver"
  type        = bool
  default     = true
}

variable "ctl_resources" {
  description = "Resources allocation for each controller instance"
  type = object({
    cpu    = number
    memory = number
  })
  default = {
    cpu    = 100
    memory = 192
  }
}

variable "node_resources" {
  description = "Resources allocation for each node instance"
  type = object({
    cpu    = number
    memory = number
  })
  default = {
    cpu    = 100
    memory = 192
  }
}

variable "ctl_count" {
  description = "Number of controller instances to run"
  type        = number
  default     = 1
}

variable "freenas_api_scheme" {
  description = "Scheme to use to connect on FreeNAS API"
  type        = string
  default     = "http"
}

variable "freenas_api_host" {
  description = "Host to connect to the FreeNAS API"
  type        = string
  default     = "freenas"
}

variable "freenas_api_port" {
  description = "Port to connect to the FreNAS API"
  type        = number
  default     = 80
}

variable "freenas_api_insecure" {
  description = "If insecure is enabled, no certificate verification will be done"
  type        = bool
  default     = false
}

variable "iscsi_zfs_parent" {
  description = "Parent ZFS dataset where zvols will be created"
  type        = string
  default     = "zpool/csi/iscsi"
}

variable "iscsi_zfs_snap_parent" {
  description = "Parent ZFS dataset where detached snapshots will be stored. Should not be nested with iscsi_zfs_parent"
  type        = string
  default     = "zpool/csi/iscsisnap"
}

variable "iscsi_zfs_reservation" {
  description = "Should ZFS reservation be used"
  type        = bool
  default     = false
}

variable "iscsi_zfs_blocksize" {
  description = "volblocksize of the zvol created through the CSI interface"
  type        = string
  default     = "16K"
}

variable "iscsi_portals" {
  description = "List of portals to connect to (can specify several for multipath)"
  type        = list(string)
  default = [
    "10.99.3.27:3260"
  ]
}

variable "iscsi_portal_group_id" {
  description = "The portal group ID to use on FreeNAS"
  type        = number
  default     = 1
}

variable "iscsi_initiator_group_id" {
  description = "The initiator group ID to use on FreeNAS"
  type        = number
  default     = 1
}

variable "iscsi_auth_type" {
  description = "iSCSI auth type : can be None, CHAP or CHAP Mutual"
  type        = string
  default     = "None"
}

variable "iscsi_auth_group_id" {
  description = "If auth is enabled, define the auth group ID from FreeNAS to use"
  type        = number
  default     = 1
}

variable "nfs_zfs_parent" {
  description = "ZFS parent dataset where NFS datasets will be created as children"
  type        = string
  default     = "zpool/csi/nfs"
}

variable "nfs_zfs_snap_parent" {
  description = "Parent ZFS dataset where detached snapshots will be stored. Should not be nested with nfs_zfs_parent"
  type        = string
  default     = "zpool/csi/nfssnap"
}

variable "nfs_zfs_quota" {
  description = "Should ZFS quota be used on datasets"
  type        = bool
  default     = false
}

variable "nfs_zfs_reservation" {
  description = "Should ZFS reservation should be used on datasets"
  type        = bool
  default     = false
}

variable "nfs_server" {
  description = "IP or hostname to reach FreeNAS NFS service"
  type        = string
  default     = "10.99.3.27"
}

variable "nfs_allowed_networks" {
  description = "List of CIDR allowed to access NFS shared created with the CSI interface"
  type        = list(string)
  default = [
    "10.99.9.0/24"
  ]
}
